@@ -1,10 +1,8 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2008-2011 Kare Sars <kare.sars@iki .fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef KSANE_BUTTON_H
 #define KSANE_BUTTON_H
@@ -37,8 +35,8 @@ public:
      * \param text is the text describing the checkbox.
      */
     KSaneButton(QWidget *parent, const QString &text);
-    KSaneButton(QWidget *parent, KSaneOption *option);
-    ~KSaneButton();
+    KSaneButton(QWidget *parent, KSaneCore::Option *option);
+    ~KSaneButton() override;
 
 Q_SIGNALS:
     void clicked(const QVariant &value);
